pygeodesy.heights._HeightBase

Package pygeodesy :: Module heights :: Class _HeightBase |
[frames] | no frames]

# Class _HeightBase

      object --+
               |
    named._Named --+
                   |
        _HeightNamed --+
                       |
                      _HeightBase

Known Subclasses:
  - geoids._GeoidBase
  - , HeightCubic
  - , HeightLSQBiSpline
  - , HeightSmoothBiSpline

(INTERNAL) Interpolator base class.

Instance Methods
height(self, lats, lons, **wrap) Interpolate the height for one or several lat-/longitudes. |
Inherited from `_HeightNamed`: `__call__`, `height_` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `__str__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| numpy Get the `numpy` module or `None`.
| scipy Get the `scipy` module or `None`.
| scipy_interpolate Get the `scipy.interpolate` module or `None`.
Inherited from `_HeightNamed`: `datum`, `kmin`, `wrap` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### height (self, lats, lons, **wrap) |
Interpolate the height for one or several lat-/longitudes. Arguments: `lats` - Latitude or latitudes (each `degrees`). `lons` - Longitude or longitudes (each `degrees`). `wrap` - Kewyord argument `wrap=False` (`bool`). Use `True` to wrap or normalize all `lats` and `lons` locationts, overriding the `knots`' setting. Returns: A single interpolated height (`float`) or a list of interpolated heights (each `float`). Raises: `HeightError` - Insufficient or unequal number of `lats` and `lons`. `SciPyError` - A `scipy` issue. `SciPyWarning` - A `scipy` warning as exception. Overrides: _HeightNamed.height

Property Details

### numpy Get the `numpy` module or `None`. Get method: _fget(inst) - Get the `property` value once and overwrite `self`, this `property` instance in the (super-)class of `self` where this property is define as a property_ROver. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(*unused) - Silently ignored, always.

### scipy Get the `scipy` module or `None`. Get method: _fget(inst) - Get the `property` value once and overwrite `self`, this `property` instance in the (super-)class of `self` where this property is define as a property_ROver. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(*unused) - Silently ignored, always.

### scipy_interpolate Get the `scipy.interpolate` module or `None`. Get method: _fget(inst) - Get the `property` value once and overwrite `self`, this `property` instance in the (super-)class of `self` where this property is define as a property_ROver. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(*unused) - Silently ignored, always.